@@ -62,7 +62,9 @@ def server_connection_check(func):
     return wrapper
 
 
-def pg_server(db_name, username, password, host_address, debug=True, server="default", send_keep_alive_probes=False, socket_idle_time=120, application_name='pg_python'):
+def pg_server(db_name, username, password, host_address, debug=True, server="default",
+              send_keep_alive_probes=False, socket_idle_time=120, application_name='pg_python',
+              port=5432):
     global print_debug_log
     # no need to make socket so, send_keep_alive_probes will no longer usefull
     params_map = {
@@ -70,6 +72,7 @@ def pg_server(db_name, username, password, host_address, debug=True, server="def
         'user'    : username,
         'password': password,
         'host'    : host_address,
+        'port'    : port,
         'application_name': application_name
     }
     db_obj = Db(params_map)
